==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>WLAN off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>ཆུང་བྲིས།</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>གྲངས་ཀའི་མཐེབ་གཞོང་བེད་སྤྱོད།</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>གྲངས་ཀའི་མཐེབ་གཞོང་སྒོ་རྒྱག</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mute on</source>
        <translation>སྒྲ་མེད།</translation>
    </message>
    <message>
        <source>Mute off</source>
        <translation>སྒྲ་ཡོད།</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>དོ་མཉམ་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>High performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>WLAN off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>ཆུང་བྲིས།</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>གྲངས་ཀའི་མཐེབ་གཞོང་བེད་སྤྱོད།</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>གྲངས་ཀའི་མཐེབ་གཞོང་སྒོ་རྒྱག</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>དོ་མཉམ་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>High performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
